% Auto-generated chapter 7 for bukhari
% Hadiths in this chapter: 15

\hadithdefcmd{bukhari}{334}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَسْفَارِهِ، حَتَّى إِذَا كُنَّا بِالْبَيْدَاءِ ـ أَوْ بِذَاتِ الْجَيْشِ ـ انْقَطَعَ عِقْدٌ لِي، فَأَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْتِمَاسِهِ، وَأَقَامَ النَّاسُ مَعَهُ، وَلَيْسُوا عَلَى مَاءٍ، فَأَتَى النَّاسُ إِلَى أَبِي بَكْرٍ الصِّدِّيقِ فَقَالُوا أَلاَ تَرَى مَا صَنَعَتْ عَائِشَةُ أَقَامَتْ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَالنَّاسِ، وَلَيْسُوا عَلَى مَاءٍ، وَلَيْسَ مَعَهُمْ مَاءٌ‏.‏ فَجَاءَ أَبُو بَكْرٍ وَرَسُولُ اللَّهِ صلى الله عليه وسلم وَاضِعٌ رَأْسَهُ عَلَى فَخِذِي قَدْ نَامَ فَقَالَ حَبَسْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم وَالنَّاسَ، وَلَيْسُوا عَلَى مَاءٍ، وَلَيْسَ مَعَهُمْ مَاءٌ‏.‏ فَقَالَتْ عَائِشَةُ فَعَاتَبَنِي أَبُو بَكْرٍ، وَقَالَ مَا شَاءَ اللَّهُ أَنْ يَقُولَ، وَجَعَلَ يَطْعُنُنِي بِيَدِهِ فِي خَاصِرَتِي، فَلاَ يَمْنَعُنِي مِنَ التَّحَرُّكِ إِلاَّ مَكَانُ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى فَخِذِي، فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ أَصْبَحَ عَلَى غَيْرِ مَاءٍ، فَأَنْزَلَ اللَّهُ آيَةَ التَّيَمُّمِ فَتَيَمَّمُوا‏.‏ فَقَالَ أُسَيْدُ بْنُ الْحُضَيْرِ مَا هِيَ بِأَوَّلِ بَرَكَتِكُمْ يَا آلَ أَبِي بَكْرٍ‏.‏ قَالَتْ فَبَعَثْنَا الْبَعِيرَ الَّذِي كُنْتُ عَلَيْهِ، فَأَصَبْنَا الْعِقْدَ تَحْتَهُ‏.‏\hadithno{334}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) We set out with Allah's Messenger (ﷺ) on one of his journeys till we reached Al- Baida' or Dhatul-Jaish, a necklace of mine was broken (and lost). Allah's Messenger (ﷺ) stayed there to search for it, and so did the people along with him. There was no water at that place, so the people went to Abu- Bakr As-Siddiq and said, "Don't you see what `Aisha has done? She has made Allah's Apostle and the people stay where there is no water and they have no water with them." Abu Bakr came while Allah's Messenger (ﷺ) was sleeping with his head on my thigh, He said, to me: "You have detained Allah's Messenger (ﷺ) and the people where there is no water and they have no water with them. So he admonished me and said what Allah wished him to say and hit me on my flank with his hand. Nothing prevented me from moving (because of pain) but the position of Allah's Messenger (ﷺ) on my thigh. Allah's Messenger (ﷺ) got up when dawn broke and there was no water. So Allah revealed the Divine Verses of Tayammum. So they all performed Tayammum. Usaid bin Hudair said, "O the family of Abu Bakr! This is not the first blessing of yours." Then the camel on which I was riding was caused to move from its place and the necklace was found beneath it}}
\hadithdefcmd{bukhari}{335}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، قَالَ حَدَّثَنَا هُشَيْمٌ، ح قَالَ وَحَدَّثَنِي سَعِيدُ بْنُ النَّضْرِ، قَالَ أَخْبَرَنَا هُشَيْمٌ، قَالَ أَخْبَرَنَا سَيَّارٌ، قَالَ حَدَّثَنَا يَزِيدُ ـ هُوَ ابْنُ صُهَيْبٍ الْفَقِيرُ ـ قَالَ أَخْبَرَنَا جَابِرُ بْنُ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أُعْطِيتُ خَمْسًا لَمْ يُعْطَهُنَّ أَحَدٌ قَبْلِي نُصِرْتُ بِالرُّعْبِ مَسِيرَةَ شَهْرٍ، وَجُعِلَتْ لِيَ الأَرْضُ مَسْجِدًا وَطَهُورًا، فَأَيُّمَا رَجُلٍ مِنْ أُمَّتِي أَدْرَكَتْهُ الصَّلاَةُ فَلْيُصَلِّ، وَأُحِلَّتْ لِيَ الْمَغَانِمُ وَلَمْ تَحِلَّ لأَحَدٍ قَبْلِي، وَأُعْطِيتُ الشَّفَاعَةَ، وَكَانَ النَّبِيُّ يُبْعَثُ إِلَى قَوْمِهِ خَاصَّةً، وَبُعِثْتُ إِلَى النَّاسِ عَامَّةً ‏"‏‏.‏\hadithno{335}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) said, "I have been given five things which were not given to any one else before me. -1. Allah made me victorious by awe, (by His frightening my enemies) for a distance of one month's journey. -2. The earth has been made for me (and for my followers) a place for praying and a thing to perform Tayammum, therefore anyone of my followers can pray wherever the time of a prayer is due. -3. The booty has been made Halal (lawful) for me yet it was not lawful for anyone else before me. -4. I have been given the right of intercession (on the Day of Resurrection). -5. Every Prophet used to be sent to his nation only but I have been sent to all mankind}}
\hadithdefcmd{bukhari}{336}{حَدَّثَنَا زَكَرِيَّاءُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا اسْتَعَارَتْ مِنْ أَسْمَاءَ قِلاَدَةً فَهَلَكَتْ، فَبَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً، فَوَجَدَهَا فَأَدْرَكَتْهُمُ الصَّلاَةُ وَلَيْسَ مَعَهُمْ مَاءٌ فَصَلَّوْا، فَشَكَوْا ذَلِكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَنْزَلَ اللَّهُ آيَةَ التَّيَمُّمِ‏.‏ فَقَالَ أُسَيْدُ بْنُ حُضَيْرٍ لِعَائِشَةَ جَزَاكِ اللَّهُ خَيْرًا، فَوَاللَّهِ مَا نَزَلَ بِكِ أَمْرٌ تَكْرَهِينَهُ إِلاَّ جَعَلَ اللَّهُ ذَلِكِ لَكِ وَلِلْمُسْلِمِينَ فِيهِ خَيْرًا‏.‏\hadithno{336}\hadithtrans{Narrated `Urwa's father:Aisha said, "I borrowed a necklace from Asma' and it was lost. So Allah's Messenger (ﷺ) sent a man to search for it and he found it. Then the time of the prayer became due and there was no water. They prayed (without ablution) and informed Allah's Messenger (ﷺ) about it, so the verse of Tayammum was revealed." Usaid bin Hudair said to `Aisha, "May Allah reward you. By Allah, whenever anything happened which you did not like, Allah brought good for you and for the Muslims in that}}
\hadithdefcmd{bukhari}{337}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنِ الأَعْرَجِ، قَالَ سَمِعْتُ عُمَيْرًا، مَوْلَى ابْنِ عَبَّاسٍ قَالَ أَقْبَلْتُ أَنَا وَعَبْدُ اللَّهِ بْنُ يَسَارٍ، مَوْلَى مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حَتَّى دَخَلْنَا عَلَى أَبِي جُهَيْمِ بْنِ الْحَارِثِ بْنِ الصِّمَّةِ الأَنْصَارِيِّ فَقَالَ أَبُو الْجُهَيْمِ أَقْبَلَ النَّبِيُّ صلى الله عليه وسلم مِنْ نَحْوِ بِئْرِ جَمَلٍ، فَلَقِيَهُ رَجُلٌ فَسَلَّمَ عَلَيْهِ، فَلَمْ يَرُدَّ عَلَيْهِ النَّبِيُّ صلى الله عليه وسلم حَتَّى أَقْبَلَ عَلَى الْجِدَارِ، فَمَسَحَ بِوَجْهِهِ وَيَدَيْهِ، ثُمَّ رَدَّ عَلَيْهِ السَّلاَمَ‏.‏\hadithno{337}\hadithtrans{Narrated Abu Juhaim Al-Ansari:The Prophet (ﷺ) came from the direction of Bir Jamal. A man met him and greeted him. But he did not return back the greeting till he went to a (mud) wall and wiped his face and hands with its dust (performed Tayammum) and then returned back the greeting}}
\hadithdefcmd{bukhari}{338}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا الْحَكَمُ، عَنْ ذَرٍّ، عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، قَالَ جَاءَ رَجُلٌ إِلَى عُمَرَ بْنِ الْخَطَّابِ فَقَالَ إِنِّي أَجْنَبْتُ فَلَمْ أُصِبِ الْمَاءَ‏.‏ فَقَالَ عَمَّارُ بْنُ يَاسِرٍ لِعُمَرَ بْنِ الْخَطَّابِ أَمَا تَذْكُرُ أَنَّا كُنَّا فِي سَفَرٍ أَنَا وَأَنْتَ فَأَمَّا أَنْتَ فَلَمْ تُصَلِّ، وَأَمَّا أَنَا فَتَمَعَّكْتُ فَصَلَّيْتُ، فَذَكَرْتُ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّمَا كَانَ يَكْفِيكَ هَكَذَا ‏"‏‏.‏ فَضَرَبَ النَّبِيُّ صلى الله عليه وسلم بِكَفَّيْهِ الأَرْضَ، وَنَفَخَ فِيهِمَا ثُمَّ مَسَحَ بِهِمَا وَجْهَهُ وَكَفَّيْهِ‏.‏\hadithno{338}\hadithtrans{Narrated `Abdur Rahman bin Abza [??]:A man came to `Umar bin Al-Khattab and said, "I became Junub but no water was available." `Ammar bin Yasir said to `Umar, "Do you remember that you and I (became Junub while both of us) were together on a journey and you didn't pray but I rolled myself on the ground and prayed? I informed the Prophet (ﷺ) about it and he said, 'It would have been sufficient for you to do like this.' The Prophet then stroked lightly the earth with his hands and then blew off the dust and passed his hands over his face and hands}}
\hadithdefcmd{bukhari}{339}{حَدَّثَنَا حَجَّاجٌ، قَالَ أَخْبَرَنَا شُعْبَةُ، أَخْبَرَنِي الْحَكَمُ، عَنْ ذَرٍّ، عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، قَالَ عَمَّارٌ بِهَذَا، وَضَرَبَ شُعْبَةُ بِيَدَيْهِ الأَرْضَ، ثُمَّ أَدْنَاهُمَا مِنْ فِيهِ، ثُمَّ مَسَحَ وَجْهَهُ وَكَفَّيْهِ‏.‏ وَقَالَ النَّضْرُ أَخْبَرَنَا شُعْبَةُ عَنِ الْحَكَمِ قَالَ سَمِعْتُ ذَرًّا يَقُولُ عَنِ ابْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى قَالَ الْحَكَمُ وَقَدْ سَمِعْتُهُ مِنِ ابْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِيهِ قَالَ قَالَ عَمَّارٌ‏.‏\hadithno{339}\hadithtrans{Narrated Sa`id bin `Abdur Rahman bin Abza:(on the authority of his father who said) `Ammar said so (the above Statement). And Shu`ba stroked lightly the earth with his hands and brought them close to his mouth (blew off the dust) and passed them over his face and then the backs of his hands. `Ammar said, "Ablution (meaning Tayammum here) is sufficient for a Muslim if water is not available}}
\hadithdefcmd{bukhari}{340}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ ذَرٍّ، عَنِ ابْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، أَنَّهُ شَهِدَ عُمَرَ وَقَالَ لَهُ عَمَّارٌ كُنَّا فِي سَرِيَّةٍ فَأَجْنَبْنَا، وَقَالَ تَفَلَ فِيهِمَا‏.‏\hadithno{340}\hadithtrans{Narrated `Abdur Rahman bin Abza:that while he was in the company of `Umar, `Ammar said to `Umar, "We were in a detachment and became Junub and I blew the dust off my hands (performed the rolling over the earth and prayed)}}
\hadithdefcmd{bukhari}{341}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ ذَرٍّ، عَنِ ابْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ عَبْدِ الرَّحْمَنِ، قَالَ قَالَ عَمَّارٌ لِعُمَرَ تَمَعَّكْتُ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ يَكْفِيكَ الْوَجْهُ وَالْكَفَّانِ ‏"‏‏.‏\hadithno{341}\hadithtrans{Narrated `Abdur Rahman bin Abza:`Ammar said to `Umar "I rolled myself in the dust and came to the Prophet (ﷺ) who said, 'Passing dusted hands over the face and the backs of the hands is sufficient for you}}
\hadithdefcmd{bukhari}{342}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ ذَرٍّ، عَنِ ابْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ الرَّحْمَنِ، قَالَ شَهِدْتُ عُمَرَ فَقَالَ لَهُ عَمَّارٌ‏.‏ وَسَاقَ الْحَدِيثَ‏.‏\hadithno{342}\hadithtrans{Narrated `Ammar:As above}}
\hadithdefcmd{bukhari}{343}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ ذَرٍّ، عَنِ ابْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، قَالَ قَالَ عَمَّارٌ فَضَرَبَ النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ الأَرْضَ، فَمَسَحَ وَجْهَهُ وَكَفَّيْهِ‏.‏\hadithno{343}\hadithtrans{Narrated `Ammar:The Prophet (ﷺ) stroked the earth with his hands and then passed them over his face and the backs of his hands (while demonstrating Tayammum)}}
\hadithdefcmd{bukhari}{344}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَوْفٌ، قَالَ حَدَّثَنَا أَبُو رَجَاءٍ، عَنْ عِمْرَانَ، قَالَ كُنَّا فِي سَفَرٍ مَعَ النَّبِيِّ صلى الله عليه وسلم وَإِنَّا أَسْرَيْنَا، حَتَّى كُنَّا فِي آخِرِ اللَّيْلِ، وَقَعْنَا وَقْعَةً وَلاَ وَقْعَةَ أَحْلَى عِنْدَ الْمُسَافِرِ مِنْهَا، فَمَا أَيْقَظَنَا إِلاَّ حَرُّ الشَّمْسِ، وَكَانَ أَوَّلَ مَنِ اسْتَيْقَظَ فُلاَنٌ ثُمَّ فُلاَنٌ ثُمَّ فُلاَنٌ ـ يُسَمِّيهِمْ أَبُو رَجَاءٍ فَنَسِيَ عَوْفٌ ـ ثُمَّ عُمَرُ بْنُ الْخَطَّابِ الرَّابِعُ، وَكَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا نَامَ لَمْ يُوقَظْ حَتَّى يَكُونَ هُوَ يَسْتَيْقِظُ، لأَنَّا لاَ نَدْرِي مَا يَحْدُثُ لَهُ فِي نَوْمِهِ، فَلَمَّا اسْتَيْقَظَ عُمَرُ، وَرَأَى مَا أَصَابَ النَّاسَ، وَكَانَ رَجُلاً جَلِيدًا، فَكَبَّرَ وَرَفَعَ صَوْتَهُ بِالتَّكْبِيرِ، فَمَا زَالَ يُكَبِّرُ وَيَرْفَعُ صَوْتَهُ بِالتَّكْبِيرِ حَتَّى اسْتَيْقَظَ لِصَوْتِهِ النَّبِيُّ صلى الله عليه وسلم فَلَمَّا اسْتَيْقَظَ شَكَوْا إِلَيْهِ الَّذِي أَصَابَهُمْ قَالَ ‏"‏ لاَ ضَيْرَ ـ أَوْ لاَ يَضِيرُ ـ ارْتَحِلُوا ‏"‏‏.‏ فَارْتَحَلَ فَسَارَ غَيْرَ بَعِيدٍ ثُمَّ نَزَلَ، فَدَعَا بِالْوَضُوءِ، فَتَوَضَّأَ وَنُودِيَ بِالصَّلاَةِ فَصَلَّى بِالنَّاسِ، فَلَمَّا انْفَتَلَ مِنْ صَلاَتِهِ إِذَا هُوَ بِرَجُلٍ مُعْتَزِلٍ لَمْ يُصَلِّ مَعَ الْقَوْمِ قَالَ ‏"‏ مَا مَنَعَكَ يَا فُلاَنُ أَنْ تُصَلِّيَ مَعَ الْقَوْمِ ‏"‏‏.‏ قَالَ أَصَابَتْنِي جَنَابَةٌ وَلاَ مَاءَ‏.‏ قَالَ ‏"‏ عَلَيْكَ بِالصَّعِيدِ، فَإِنَّهُ يَكْفِيكَ ‏"‏‏.‏ ثُمَّ سَارَ النَّبِيُّ صلى الله عليه وسلم فَاشْتَكَى إِلَيْهِ النَّاسُ مِنَ الْعَطَشِ فَنَزَلَ، فَدَعَا فُلاَنًا ـ كَانَ يُسَمِّيهِ أَبُو رَجَاءٍ نَسِيَهُ عَوْفٌ ـ وَدَعَا عَلِيًّا فَقَالَ ‏"‏ اذْهَبَا فَابْتَغِيَا الْمَاءَ ‏"‏‏.‏ فَانْطَلَقَا فَتَلَقَّيَا امْرَأَةً بَيْنَ مَزَادَتَيْنِ ـ أَوْ سَطِيحَتَيْنِ ـ مِنْ مَاءٍ عَلَى بَعِيرٍ لَهَا، فَقَالاَ لَهَا أَيْنَ الْمَاءُ قَالَتْ عَهْدِي بِالْمَاءِ أَمْسِ هَذِهِ السَّاعَةَ، وَنَفَرُنَا خُلُوفًا‏.‏ قَالاَ لَهَا انْطَلِقِي إِذًا‏.‏ قَالَتْ إِلَى أَيْنَ قَالاَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَتِ الَّذِي يُقَالُ لَهُ الصَّابِئُ قَالاَ هُوَ الَّذِي تَعْنِينَ فَانْطَلِقِي‏.‏ فَجَاءَا بِهَا إِلَى النَّبِيِّ صلى الله عليه وسلم وَحَدَّثَاهُ الْحَدِيثَ قَالَ فَاسْتَنْزَلُوهَا عَنْ بَعِيرِهَا وَدَعَا النَّبِيُّ صلى الله عليه وسلم بِإِنَاءٍ، فَفَرَّغَ فِيهِ مِنْ أَفْوَاهِ الْمَزَادَتَيْنِ ـ أَوِ السَّطِيحَتَيْنِ ـ وَأَوْكَأَ أَفْوَاهَهُمَا، وَأَطْلَقَ الْعَزَالِيَ، وَنُودِيَ فِي النَّاسِ اسْقُوا وَاسْتَقُوا‏.‏ فَسَقَى مَنْ شَاءَ، وَاسْتَقَى مَنْ شَاءَ، وَكَانَ آخِرَ ذَاكَ أَنْ أَعْطَى الَّذِي أَصَابَتْهُ الْجَنَابَةُ إِنَاءً مِنْ مَاءٍ قَالَ ‏"‏ اذْهَبْ، فَأَفْرِغْهُ عَلَيْكَ ‏"‏‏.‏ وَهْىَ قَائِمَةٌ تَنْظُرُ إِلَى مَا يُفْعَلُ بِمَائِهَا، وَايْمُ اللَّهِ لَقَدْ أُقْلِعَ عَنْهَا، وَإِنَّهُ لَيُخَيَّلُ إِلَيْنَا أَنَّهَا أَشَدُّ مِلأَةً مِنْهَا حِينَ ابْتَدَأَ فِيهَا، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اجْمَعُوا لَهَا ‏"‏‏.‏ فَجَمَعُوا لَهَا مِنْ بَيْنِ عَجْوَةٍ وَدَقِيقَةٍ وَسَوِيقَةٍ، حَتَّى جَمَعُوا لَهَا طَعَامًا، فَجَعَلُوهَا فِي ثَوْبٍ، وَحَمَلُوهَا عَلَى بَعِيرِهَا، وَوَضَعُوا الثَّوْبَ بَيْنَ يَدَيْهَا قَالَ لَهَا ‏"‏ تَعْلَمِينَ مَا رَزِئْنَا مِنْ مَائِكِ شَيْئًا، وَلَكِنَّ اللَّهَ هُوَ الَّذِي أَسْقَانَا ‏"‏‏.‏ فَأَتَتْ أَهْلَهَا، وَقَدِ احْتَبَسَتْ عَنْهُمْ قَالُوا مَا حَبَسَكِ يَا فُلاَنَةُ قَالَتِ الْعَجَبُ، لَقِيَنِي رَجُلاَنِ فَذَهَبَا بِي إِلَى هَذَا الَّذِي يُقَالُ لَهُ الصَّابِئُ، فَفَعَلَ كَذَا وَكَذَا، فَوَاللَّهِ إِنَّهُ لأَسْحَرُ النَّاسِ مِنْ بَيْنِ هَذِهِ وَهَذِهِ‏.‏ وَقَالَتْ بِإِصْبَعَيْهَا الْوُسْطَى وَالسَّبَّابَةِ، فَرَفَعَتْهُمَا إِلَى السَّمَاءِ ـ تَعْنِي السَّمَاءَ وَالأَرْضَ ـ أَوْ إِنَّهُ لَرَسُولُ اللَّهِ حَقًّا، فَكَانَ الْمُسْلِمُونَ بَعْدَ ذَلِكَ يُغِيرُونَ عَلَى مَنْ حَوْلَهَا مِنَ الْمُشْرِكِينَ، وَلاَ يُصِيبُونَ الصِّرْمَ الَّذِي هِيَ مِنْهُ، فَقَالَتْ يَوْمًا لِقَوْمِهَا مَا أُرَى أَنَّ هَؤُلاَءِ الْقَوْمَ يَدَعُونَكُمْ عَمْدًا، فَهَلْ لَكُمْ فِي الإِسْلاَمِ فَأَطَاعُوهَا فَدَخَلُوا فِي الإِسْلاَمِ‏.‏\hadithno{344}\hadithtrans{Narrated `Imran:Once we were traveling with the Prophet (ﷺ) and we carried on traveling till the last part of the night and then we (halted at a place) and slept (deeply). There is nothing sweeter than sleep for a traveler in the last part of the night. So it was only the heat of the sun that made us to wake up and the first to wake up was so and so, then so and so and then so and so (the narrator `Auf said that Abu Raja' had told him their names but he had forgotten them) and the fourth person to wake up was `Umar bin Al- Khattab. And whenever the Prophet (ﷺ) used to sleep, nobody would wake him up till he himself used to get up as we did not know what was happening (being revealed) to him in his sleep. So, `Umar got up and saw the condition of the people, and he was a strict man, so he said, "Allahu Akbar" and raised his voice with Takbir, and kept on saying loudly till the Prophet (ﷺ) got up because of it. When he got up, the people informed him about what had happened to them. He said, "There is no harm (or it will not be harmful). Depart!" So they departed from that place, and after covering some distance the Prophet (ﷺ) stopped and asked for some water to perform the ablution. So he performed the ablution and the call for the prayer was pronounced and he led the people in prayer. After he finished from the prayer, he saw a man sitting aloof who had not prayed with the people. He asked, "O so and so! What has prevented you from praying with us?" He replied, "I am Junub and there is no water. " The Prophet (ﷺ) said, "Perform Tayammum with (clean) earth and that is sufficient for you." Then the Prophet (ﷺ) proceeded on and the people complained to him of thirst. Thereupon he got down and called a person (the narrator `Auf added that Abu Raja' had named him but he had forgotten) and `Ali, and ordered them to go and bring water. So they went in search of water and met a woman who was sitting on her camel between two bags of water. They asked, "Where can we find water?" She replied, "I was there (at the place of water) this hour yesterday and my people are behind me." They requested her to accompany them. She asked, "Where?" They said, "To Allah's Messenger (ﷺ) ." She said, "Do you mean the man who is called the Sabi, (with a new religion)?" They replied, "Yes, the same person. So come along." They brought her to the Prophet (ﷺ) and narrated the whole story. He said, "Help her to dismount." The Prophet (ﷺ) asked for a pot, then he opened the mouths of the bags and poured some water into the pot. Then he closed the big openings of the bags and opened the small ones and the people were called upon to drink and water their animals. So they all watered their animals and they (too) all quenched their thirst and also gave water to others and last of all the Prophet (ﷺ) gave a pot full of water to the person who was Junub and told him to pour it over his body. The woman was standing and watching all that which they were doing with her water. By Allah, when her water bags were returned they looked like as if they were more full (of water) than they had been before (Miracle of Allah's Messenger (ﷺ)) Then the Prophet (ﷺ) ordered us to collect something for her; so dates, flour and Sawiq were collected which amounted to a good meal that was put in a piece of cloth. She was helped to ride on her camel and that cloth full of foodstuff was also placed in front of her and then the Prophet (ﷺ) said to her, "We have not taken your water but Allah has given water to us." She returned home late. Her relatives asked her: "O so and so what has delayed you?" She said, "A strange thing! Two men met me and took me to the man who is called the Sabi' and he did such and such a thing. By Allah, he is either the greatest magician between this and this (gesturing with her index and middle fingers raising them towards the sky indicating the heaven and the earth) or he is Allah's true Apostle." Afterwards the Muslims used to attack the pagans around her abode but never touched her village. One day she said to her people, "I think that these people leave you purposely. Have you got any inclination to Islam?" They obeyed her and all of them embraced Islam. Abu `Abdullah said: The word Saba'a means "The one who has deserted his old religion and embraced a new religion." Abul 'Ailya [??] said, "The S`Abis are a sect of people of the Scripture who recite the Book of Psalms}}
\hadithdefcmd{bukhari}{345}{حَدَّثَنَا بِشْرُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ ـ هُوَ غُنْدَرٌ ـ عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ أَبِي وَائِلٍ، قَالَ قَالَ أَبُو مُوسَى لِعَبْدِ اللَّهِ بْنِ مَسْعُودٍ إِذَا لَمْ يَجِدِ الْمَاءَ لاَ يُصَلِّي‏.‏ قَالَ عَبْدُ اللَّهِ لَوْ رَخَّصْتُ لَهُمْ فِي هَذَا، كَانَ إِذَا وَجَدَ أَحَدُهُمُ الْبَرْدَ قَالَ هَكَذَا ـ يَعْنِي تَيَمَّمَ وَصَلَّى ـ قَالَ قُلْتُ فَأَيْنَ قَوْلُ عَمَّارٍ لِعُمَرَ قَالَ إِنِّي لَمْ أَرَ عُمَرَ قَنِعَ بِقَوْلِ عَمَّارٍ‏.‏\hadithno{345}\hadithtrans{Narrated Abu Wail:Abu Musa said to `Abdullah bin Mas`ud, "If one does not find water (for ablution) can he give up the prayer?" `Abdullah replied, "If you give the permission to perform Tayammum they will perform Tayammum even if water was available if one of them found it cold." Abu Musa said, "What about the statement of `Ammar to `Umar?" `Abdullah replied, "`Umar was not satisfied by his statement}}
\hadithdefcmd{bukhari}{346}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا الأَعْمَشُ، قَالَ سَمِعْتُ شَقِيقَ بْنَ سَلَمَةَ، قَالَ كُنْتُ عِنْدَ عَبْدِ اللَّهِ وَأَبِي مُوسَى فَقَالَ لَهُ أَبُو مُوسَى أَرَأَيْتَ يَا أَبَا عَبْدِ الرَّحْمَنِ إِذَا أَجْنَبَ فَلَمْ يَجِدْ، مَاءً كَيْفَ يَصْنَعُ فَقَالَ عَبْدُ اللَّهِ لاَ يُصَلِّي حَتَّى يَجِدَ الْمَاءَ‏.‏ فَقَالَ أَبُو مُوسَى فَكَيْفَ تَصْنَعُ بِقَوْلِ عَمَّارٍ حِينَ قَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ كَانَ يَكْفِيكَ ‏"‏ قَالَ أَلَمْ تَرَ عُمَرَ لَمْ يَقْنَعْ بِذَلِكَ‏.‏ فَقَالَ أَبُو مُوسَى فَدَعْنَا مِنْ قَوْلِ عَمَّارٍ، كَيْفَ تَصْنَعُ بِهَذِهِ الآيَةِ فَمَا دَرَى عَبْدُ اللَّهِ مَا يَقُولُ فَقَالَ إِنَّا لَوْ رَخَّصْنَا لَهُمْ فِي هَذَا لأَوْشَكَ إِذَا بَرَدَ عَلَى أَحَدِهِمُ الْمَاءُ أَنْ يَدَعَهُ وَيَتَيَمَّمَ‏.‏ فَقُلْتُ لِشَقِيقٍ فَإِنَّمَا كَرِهَ عَبْدُ اللَّهِ لِهَذَا قَالَ نَعَمْ‏.‏\hadithno{346}\hadithtrans{Narrated Shaqiq bin Salama:I was with `Abdullah and Abu Musa; the latter asked the former, "O Abu `Abdur-Rahman! What is your opinion if somebody becomes Junub and no water is available?" `Abdullah replied, "Do not pray till water is found." Abu Musa said, "What do you say about the statement of `Ammar (who was ordered by the Prophet (ﷺ) to perform Tayammum). The Prophet (ﷺ) said to him: "Perform Tayammum and that would be sufficient." `Abdullah replied, "Don't you see that `Umar was not satisfied by `Ammar's statement?" Abu- Musa said, "All right, leave `Ammar's statement, but what will you say about this verse (of Tayammum)?" `Abdullah kept quiet and then said, "If we allowed it, then they would probably perform Tayammum even if water was available, if one of them found it (water) cold." The narrator added, "I said to Shaqiq, "Then did `Abdullah dislike to perform Tayammum because of this?" He replied, "Yes}}
\hadithdefcmd{bukhari}{347}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ، قَالَ أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، قَالَ كُنْتُ جَالِسًا مَعَ عَبْدِ اللَّهِ وَأَبِي مُوسَى الأَشْعَرِيِّ فَقَالَ لَهُ أَبُو مُوسَى لَوْ أَنَّ رَجُلاً أَجْنَبَ، فَلَمْ يَجِدِ الْمَاءَ شَهْرًا، أَمَا كَانَ يَتَيَمَّمُ وَيُصَلِّي فَكَيْفَ تَصْنَعُونَ بِهَذِهِ الآيَةِ فِي سُورَةِ الْمَائِدَةِ ‏\{‏فَلَمْ تَجِدُوا مَاءً فَتَيَمَّمُوا صَعِيدًا طَيِّبًا‏\}‏ فَقَالَ عَبْدُ اللَّهِ لَوْ رُخِّصَ لَهُمْ فِي هَذَا لأَوْشَكُوا إِذَا بَرَدَ عَلَيْهِمُ الْمَاءُ أَنْ يَتَيَمَّمُوا الصَّعِيدَ‏.‏ قُلْتُ وَإِنَّمَا كَرِهْتُمْ هَذَا لِذَا قَالَ نَعَمْ‏.‏ فَقَالَ أَبُو مُوسَى أَلَمْ تَسْمَعْ قَوْلَ عَمَّارٍ لِعُمَرَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَاجَةٍ فَأَجْنَبْتُ، فَلَمْ أَجِدِ الْمَاءَ، فَتَمَرَّغْتُ فِي الصَّعِيدِ كَمَا تَمَرَّغُ الدَّابَّةُ، فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنَّمَا كَانَ يَكْفِيكَ أَنْ تَصْنَعَ هَكَذَا ‏"‏‏.‏ فَضَرَبَ بِكَفِّهِ ضَرْبَةً عَلَى الأَرْضِ ثُمَّ نَفَضَهَا، ثُمَّ مَسَحَ بِهَا ظَهْرَ كَفِّهِ بِشِمَالِهِ، أَوْ ظَهْرَ شِمَالِهِ بِكَفِّهِ، ثُمَّ مَسَحَ بِهِمَا وَجْهَهُ فَقَالَ عَبْدُ اللَّهِ أَفَلَمْ تَرَ عُمَرَ لَمْ يَقْنَعْ بِقَوْلِ عَمَّارٍ وَزَادَ يَعْلَى عَنِ الأَعْمَشِ عَنْ شَقِيقٍ كُنْتُ مَعَ عَبْدِ اللَّهِ وَأَبِي مُوسَى فَقَالَ أَبُو مُوسَى أَلَمْ تَسْمَعْ قَوْلَ عَمَّارٍ لِعُمَرَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَنِي أَنَا وَأَنْتَ فَأَجْنَبْتُ فَتَمَعَّكْتُ بِالصَّعِيدِ، فَأَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْنَاهُ فَقَالَ ‏"‏ إِنَّمَا كَانَ يَكْفِيكَ هَكَذَا ‏"‏‏.‏ وَمَسَحَ وَجْهَهُ وَكَفَّيْهِ وَاحِدَةً\hadithno{347}\hadithtrans{Narrated Al-A`mash:Shaqiq said, "While I was sitting with `Abdullah and Abu Musa Al-Ash`ari, the latter asked the former, 'If a person becomes Junub and does not find water for one month, can he perform Tayammum and offer his prayer?' (He replied in the negative). Abu Musa said, 'What do you say about this verse from Sura "Al-Ma'ida": When you do not find water then perform Tayammum with clean earth? `Abdullah replied, 'If we allowed it then they would probably perform Tayammum with clean earth even if water were available but cold.' I said to Shaqiq, 'You then disliked to perform Tayammum because of this?' Shaqiq said, 'Yes.' (Shaqiq added), "Abu Musa said, 'Haven't you heard the statement of `Ammar to `Umar? He said: I was sent out by Allah's Messenger (ﷺ) for some job and I became Junub and could not find water so I rolled myself over the dust (clean earth) like an animal does, and when I told the Prophet (ﷺ) of that he said, 'Like this would have been sufficient.' The Prophet (ﷺ) (saying so) lightly stroked the earth with his hand once and blew it off, then passed his (left) hand over the back of his right hand or his (right) hand over the back of his left hand and then passed them over his face.' So `Abdullah said to Abu- Musa, 'Don't you know that `Umar was not satisfied with `Ammar's statement?' " Narrated Shaqiq: While I was with `Abdullah and Abu Musa, the latter said to the former, "Haven't you heard the statement of `Ammar to `Umar? He said, "Allah's Messenger (ﷺ) sent you and me out and I became Junub and rolled myself in the dust (clean earth) (for Tayammum). When we came to Allah's Apostle I told him about it and he said, 'This would have been sufficient,' passing his hands over his face and the backs of his hands once only}}
\hadithdefcmd{bukhari}{348}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا عَوْفٌ، عَنْ أَبِي رَجَاءٍ، قَالَ حَدَّثَنَا عِمْرَانُ بْنُ حُصَيْنٍ الْخُزَاعِيُّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً مُعْتَزِلاً لَمْ يُصَلِّ فِي الْقَوْمِ فَقَالَ ‏"‏ يَا فُلاَنُ مَا مَنَعَكَ أَنْ تُصَلِّيَ فِي الْقَوْمِ ‏"‏‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ، أَصَابَتْنِي جَنَابَةٌ وَلاَ مَاءَ‏.‏ قَالَ ‏"‏ عَلَيْكَ بِالصَّعِيدِ فَإِنَّهُ يَكْفِيكَ ‏"‏‏.‏\hadithno{348}\hadithtrans{Narrated `Imran bin Husain Al-Khuza`i:Allah's Messenger (ﷺ) saw a person sitting aloof and not praying with the people. He asked him, "O so and so! What prevented you from offering the prayer with the people?" He replied, "O Allah's Messenger (ﷺ)! I am Junub and there is no water." The Prophet (ﷺ) said, "Perform Tayammum with clean earth and that will be sufficient for you}}
